@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (c) 2002-2009 The Xfce development team. All rights reserved.
+# Copyright (c) 2002-2020 The Xfce development team. All rights reserved.
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the Free
@@ -23,17 +23,16 @@
 
 (type xdt-autogen) >/dev/null 2>&1 || {
   cat >&2 <<EOF
-autogen.sh: You don't seem to have the Xfce development tools (at least
-            version $XDT_REQUIRED_VERSION) installed on your system, which
-            are required to build this software.
+autogen.sh: You don't seem to have the Xfce development tools installed on your system, 
+            which are required to build this software.
             Please install the xfce4-dev-tools package first; it is available
-            from http://www.xfce.org/.
+            from your distribution or https://www.xfce.org/.
 EOF
   exit 1
 }
 
 test -d m4 || mkdir m4
 
-XDT_AUTOGEN_REQUIRED_VERSION="4.7.2" exec xdt-autogen "$@"
+XDT_AUTOGEN_REQUIRED_VERSION="4.14.0" exec xdt-autogen "$@"
 
 # vi:set ts=2 sw=2 et ai:
