@@ -273,23 +273,36 @@ set_status_text (GSLockPlug *plug,
     }
 }
 
-static void
-date_time_update (GSLockPlug *plug) {
+static gboolean
+date_time_update (gpointer user_data) {
+    GSLockPlug *plug = user_data;
     GDateTime *datetime;
     gchar     *datetime_format;
     gchar     *str;
 
     datetime = g_date_time_new_now_local ();
+    if (datetime == NULL)
+        goto out;
+
     /* TRANSLATORS: adjust this accordingly for your locale format */
     datetime_format = g_date_time_format (datetime, NC_("Date",
                                                         "%A, %B %e   %H:%M"));
+    if (datetime_format == NULL)
+        goto out_datetime;
 
     str = g_strdup_printf ("<b>%s</b>", datetime_format);
+    if (str == NULL)
+        goto out_str;
+
     gtk_label_set_markup (GTK_LABEL (plug->priv->auth_datetime_label), str);
     g_free (str);
 
+out_str:
     g_free (datetime_format);
+out_datetime:
     g_date_time_unref (datetime);
+out:
+    return TRUE;
 }
 
 void
@@ -347,7 +360,9 @@ gs_lock_plug_response (GSLockPlug *plug,
 }
 
 static gboolean
-response_cancel_idle_cb (GSLockPlug *plug) {
+response_cancel_idle (gpointer user_data) {
+    GSLockPlug *plug = user_data;
+
     plug->priv->response_idle_id = 0;
 
     gs_lock_plug_response (plug, GS_LOCK_PLUG_RESPONSE_CANCEL);
@@ -356,7 +371,9 @@ response_cancel_idle_cb (GSLockPlug *plug) {
 }
 
 static gboolean
-dialog_timed_out (GSLockPlug *plug) {
+dialog_timed_out (gpointer user_data) {
+    GSLockPlug *plug = user_data;
+
     gs_lock_plug_set_sensitive (plug, FALSE);
     set_status_text (plug, _("Time has expired."));
 
@@ -366,9 +383,7 @@ dialog_timed_out (GSLockPlug *plug) {
 
     remove_response_idle (plug);
 
-    plug->priv->response_idle_id = g_timeout_add_seconds (2,
-                                   (GSourceFunc)response_cancel_idle_cb,
-                                   plug);
+    plug->priv->response_idle_id = g_timeout_add_seconds (2, response_cancel_idle, plug);
     return FALSE;
 }
 
@@ -404,10 +419,7 @@ is_capslock_on (void) {
 static void
 restart_cancel_timeout (GSLockPlug *plug) {
     remove_cancel_timeout (plug);
-    plug->priv->cancel_timeout_id = g_timeout_add_seconds (
-                                       DIALOG_TIMEOUT_SEC,
-                                       (GSourceFunc)dialog_timed_out,
-                                       plug);
+    plug->priv->cancel_timeout_id = g_timeout_add_seconds (DIALOG_TIMEOUT_SEC, dialog_timed_out, plug);
 }
 
 void
@@ -1363,9 +1375,7 @@ switch_user_button_clicked (GtkButton  *button,
 
     gs_lock_plug_set_sensitive (plug, FALSE);
 
-    plug->priv->response_idle_id = g_timeout_add_seconds (2,
-            (GSourceFunc)response_cancel_idle_cb,
-            plug);
+    plug->priv->response_idle_id = g_timeout_add_seconds (2, response_cancel_idle, plug);
 
     gs_lock_plug_set_busy (plug);
     do_user_switch (plug);
@@ -1536,7 +1546,7 @@ gs_lock_plug_init (GSLockPlug *plug) {
     clear_clipboards (plug);
 
     gs_lock_plug_add_login_window (plug);
-    plug->priv->datetime_timeout_id = g_timeout_add_seconds (60, (GSourceFunc) date_time_update, plug);
+    plug->priv->datetime_timeout_id = g_timeout_add_seconds (60, date_time_update, plug);
 
     /* Layout indicator */
 #ifdef WITH_KBD_LAYOUT_INDICATOR
