@@ -186,7 +186,7 @@ G_BEGIN_DECLS
 #define DEFAULT_KEY_USER_SWITCH_ENABLED TRUE
 
 /**
- * Blank screensaver DPMS sleep timeout
+ * Blank screensaver DPMS sleep timeout (seconds)
  * This value controls the timeout after blanking the screen to suspend the display.
  * A value of 0 means that it is disabled.
  */
@@ -194,7 +194,7 @@ G_BEGIN_DECLS
 #define DEFAULT_KEY_DPMS_SLEEP_AFTER 5
 
 /**
- * Blank screensaver DPMS power timeout
+ * Blank screensaver DPMS power timeout (minutes)
  * This value controls the timeout after blanking the screen to power off the display.
  * A value of 0 means that it is disabled.
  */
@@ -228,9 +228,9 @@ typedef struct
     guint            keyboard_displayed : 1;       /* Whether the keyboard is displayed */
     guint            status_message_enabled : 1; /* show the status message in the lock */
     guint            timeout;        /* how much idle time before activation */
-    guint            lock_timeout;   /* how long after activation locking starts */
-    guint            logout_timeout; /* how long until the logout option appears */
-    guint            cycle;          /* how long each theme should run */
+    guint            lock_timeout;   /* how many minutes after activation locking starts */
+    guint            logout_timeout; /* how many seconds until the logout option appears */
+    guint            cycle;          /* how many seconds each theme should run */
     guint            fullscreen_inhibit : 1; /* inhibit screensaver when an application is fullscreen */
 
     char            *logout_command;   /* command to use to logout */
