@@ -1838,7 +1838,7 @@ widget_set_best_visual (GtkWidget *widget) {
 }
 
 static gboolean
-setup_treeview_idle (gpointer data) {
+setup_treeview_idle (gpointer user_data) {
     GtkWidget *preview;
     GtkWidget *treeview;
 
@@ -2133,7 +2133,7 @@ configure_capplet (void) {
     g_signal_connect (fullscreen_preview_next, "clicked",
                       G_CALLBACK (fullscreen_preview_next_cb), NULL);
 
-    g_idle_add ((GSourceFunc)setup_treeview_idle, NULL);
+    g_idle_add (setup_treeview_idle, NULL);
 }
 
 static void
